local AddonName, AddonTable = ...
local L = AddonTable.Localize
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")

function DRFrame_OnLoad()

	-- Create SavedVariables if they don't exist already
	if DRConfig == "" or DRConfig == nil then
		DRConfig = {
			["DeclineDuel"] = 'ON',
			["ShowChatMessage"] = 'ON',
			["ShowLoadMessage"] = 'ON'
		}
	end
	
	-- This variable tracks the total number of blocked duels across all of your characters
	if GlobalDC == "" or GlobalDC == nil then
		GlobalDC = 0
	end
	
	-- This variable tracks the total number of blocked duels on a single character
	if DuelsDeclined == nil or DuelsDeclined == "" then
		DuelsDeclined = 0
	end
	
	DRFrame:RegisterEvent("ADDON_LOADED")
	DRFrame:RegisterEvent("DUEL_REQUESTED")
	
	-- already hidden by default, but just in case...
	DRFrame:Hide()

SlashCmdList["DUELRESPONSE"] = drconfig;
	SLASH_DUELRESPONSE1 = "/dr"
	
end

function DRFrame_OnEvent(self, event, arg1)

if event == "ADDON_LOADED" and arg1 == "DuelResponse" then

	if DRConfig.ShowLoadMessage == "ON" then
		-- Show these messages in chat when the addon is loaded
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r v" .. GetAddOnMetadata("DuelResponse", "Version") .. L[" loaded successfully."])
	else
		return
	end
elseif event == "DUEL_REQUESTED" then

	if DRConfig.DeclineDuel == "OFF" then
		-- Check to see if the player has Resurrection Sickness; decline the request if they do.
		if UnitDebuff("player", L["Resurrection Sickness"]) then
			if DRConfig.ShowChatMessage == "ON" then
				DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Declined a duel request from "] .. arg1 .. L[" because you have "] .. GetSpellLink(15007) .. ".")
			end
			
			CancelDuel()
			increment_counters()
		else
			if IsControlKeyDown() or IsAltKeyDown() then
				return
			else
				if UnitIsAFK("player") == true then
					-- If the player is not blocking duels, but is marked as AFK, decline the request.
					CancelDuel()
					increment_counters()
			
					if DRConfig.ShowChatMessage == "ON" then
						DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. arg1 .. L[" challenged you while you were marked as Away."])
					end
				elseif UnitIsDND("player") == true then
					-- If the player is not blocking duels, but is marked as Busy, decline the request.
					CancelDuel()
					increment_counters()
			
					if DRConfig.ShowChatMessage == "ON" then
						DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. arg1 .. L[" challenged you while you were marked as Busy."])
					end
				end
			end
		end
	elseif DRConfig.DeclineDuel == "ON" then
		-- If the player is blocking duels, holding down either Control or Alt will allow a request to pass through
		if IsControlKeyDown() or IsAltKeyDown() then
			return
		else
		-- If the player is blocking duels, decline the request and increment the counters
			CancelDuel()
			increment_counters()
			
			if DRConfig.ShowChatMessage == "ON" then
				DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Declined a duel request from "] .. arg1 .. ".")
			end
		end
	else
		return
	end
end
end
	
function increment_counters()

-- Set up variables
local x = tonumber(GlobalDC)
local y = tonumber(DuelsDeclined)

-- Increment counters by 1
x = x + 1
y = y + 1

-- Save new variables
GlobalDC = x
DuelsDeclined = y

end

function drconfig(msg, editbox)

if msg == "" or msg == nil then
	-- Toggles whether or not duel requests will be blocked
	if DRConfig.DeclineDuel == "ON" then
		DRConfig.DeclineDuel = 'OFF'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Duel requests will not be declined."])
	elseif DRConfig.DeclineDuel == "OFF" then
		DRConfig.DeclineDuel = 'ON'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Duel requests will be declined."])
	end
elseif msg == "chat" then
	-- Toggles whether or not blocked requests will be displayed in the chat panel
	if DRConfig.ShowChatMessage == "ON" then
		DRConfig.ShowChatMessage = 'OFF'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Chat log messages have been turned off."])
	elseif DRConfig.ShowChatMessage == "OFF" then
		DRConfig.ShowChatMessage = 'ON'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Chat log messages have been turned on."])
	end
elseif msg == "load" then
	-- Toggles the visibility of the messages displayed on game load
	if DRConfig.ShowLoadMessage == "ON" then
		DRConfig.ShowLoadMessage = 'OFF'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Load message disabled."])
	elseif DRConfig.ShowLoadMessage == "OFF" then
		DRConfig.ShowLoadMessage = 'ON'
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Load message enabled."])
	end
elseif msg == "stats" then
	DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Total duels blocked: "] .. tonumber(GlobalDC) .. " (" ..  UnitName("player") .. ": " .. tonumber(DuelsDeclined) .. ")")
end

end